"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.build.v1.build_pb2
import qwak.fitness_service.fitness_pb2
import qwak.user_application.common.v0.resources_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PhaseStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhaseStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhaseStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHASE_STATUS_INVALID: _PhaseStatus.ValueType  # 0
    PHASE_STATUS_IN_PROGRESS: _PhaseStatus.ValueType  # 1
    PHASE_STATUS_SUCCESSFUL: _PhaseStatus.ValueType  # 2
    PHASE_STATUS_FAILED: _PhaseStatus.ValueType  # 3
    PHASE_STATUS_CANCELLED: _PhaseStatus.ValueType  # 4

class PhaseStatus(_PhaseStatus, metaclass=_PhaseStatusEnumTypeWrapper): ...

PHASE_STATUS_INVALID: PhaseStatus.ValueType  # 0
PHASE_STATUS_IN_PROGRESS: PhaseStatus.ValueType  # 1
PHASE_STATUS_SUCCESSFUL: PhaseStatus.ValueType  # 2
PHASE_STATUS_FAILED: PhaseStatus.ValueType  # 3
PHASE_STATUS_CANCELLED: PhaseStatus.ValueType  # 4
global___PhaseStatus = PhaseStatus

class _FailureReason:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FailureReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FailureReason.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FAILURE_REASON_UNSPECIFIED: _FailureReason.ValueType  # 0
    FAILURE_REASON_AVAILABLE_IN_LOGS: _FailureReason.ValueType  # 1
    FAILURE_REASON_OUT_OF_MEMORY: _FailureReason.ValueType  # 2

class FailureReason(_FailureReason, metaclass=_FailureReasonEnumTypeWrapper): ...

FAILURE_REASON_UNSPECIFIED: FailureReason.ValueType  # 0
FAILURE_REASON_AVAILABLE_IN_LOGS: FailureReason.ValueType  # 1
FAILURE_REASON_OUT_OF_MEMORY: FailureReason.ValueType  # 2
global___FailureReason = FailureReason

class SaveFrameworkModelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_FIELD_NUMBER: builtins.int
    @property
    def spec(self) -> qwak.build.v1.build_pb2.FrameworkModelsSpec: ...
    def __init__(
        self,
        *,
        spec: qwak.build.v1.build_pb2.FrameworkModelsSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> None: ...

global___SaveFrameworkModelsRequest = SaveFrameworkModelsRequest

class SaveFrameworkModelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SaveFrameworkModelsResponse = SaveFrameworkModelsResponse

class RegisterBuildRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILDID_FIELD_NUMBER: builtins.int
    COMMITID_FIELD_NUMBER: builtins.int
    MODELID_FIELD_NUMBER: builtins.int
    BUILDCONFIG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    STEPS_FIELD_NUMBER: builtins.int
    buildId: builtins.str
    commitId: builtins.str
    modelId: builtins.str
    buildConfig: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def steps(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        buildId: builtins.str = ...,
        commitId: builtins.str = ...,
        modelId: builtins.str = ...,
        buildConfig: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        steps: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buildConfig", b"buildConfig", "buildId", b"buildId", "commitId", b"commitId", "modelId", b"modelId", "steps", b"steps", "tags", b"tags"]) -> None: ...

global___RegisterBuildRequest = RegisterBuildRequest

class RegisterBuildResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterBuildResponse = RegisterBuildResponse

class UpdateBuildStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILDID_FIELD_NUMBER: builtins.int
    BUILD_STATUS_FIELD_NUMBER: builtins.int
    buildId: builtins.str
    build_status: qwak.build.v1.build_pb2.BuildStatus.ValueType
    def __init__(
        self,
        *,
        buildId: builtins.str = ...,
        build_status: qwak.build.v1.build_pb2.BuildStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buildId", b"buildId", "build_status", b"build_status"]) -> None: ...

global___UpdateBuildStatusRequest = UpdateBuildStatusRequest

class UpdateBuildStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateBuildStatusResponse = UpdateBuildStatusResponse

class RegisterExperimentTrackingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class MetricsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.float
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BUILD_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    @property
    def params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def metrics(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.float]: ...
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        metrics: collections.abc.Mapping[builtins.str, builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "metrics", b"metrics", "params", b"params"]) -> None: ...

global___RegisterExperimentTrackingRequest = RegisterExperimentTrackingRequest

class RegisterExperimentTrackingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterExperimentTrackingResponse = RegisterExperimentTrackingResponse

class RegisterModelSchemaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    MODEL_SCHEMA_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    @property
    def model_schema(self) -> qwak.build.v1.build_pb2.ModelSchema: ...
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        model_schema: qwak.build.v1.build_pb2.ModelSchema | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_schema", b"model_schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "model_schema", b"model_schema"]) -> None: ...

global___RegisterModelSchemaRequest = RegisterModelSchemaRequest

class RegisterModelSchemaResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterModelSchemaResponse = RegisterModelSchemaResponse

class GetBuildRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___GetBuildRequest = GetBuildRequest

class GetBuildResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_FIELD_NUMBER: builtins.int
    @property
    def build(self) -> qwak.build.v1.build_pb2.Build: ...
    def __init__(
        self,
        *,
        build: qwak.build.v1.build_pb2.Build | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build", b"build"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build"]) -> None: ...

global___GetBuildResponse = GetBuildResponse

class ListBuildsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_ID_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    branch_id: builtins.str
    @property
    def filter(self) -> qwak.build.v1.build_pb2.BuildFilter: ...
    model_uuid: builtins.str
    def __init__(
        self,
        *,
        branch_id: builtins.str = ...,
        filter: qwak.build.v1.build_pb2.BuildFilter | None = ...,
        model_uuid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "filter", b"filter", "model_uuid", b"model_uuid"]) -> None: ...

global___ListBuildsRequest = ListBuildsRequest

class ListBuildsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_FIELD_NUMBER: builtins.int
    @property
    def build(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.build.v1.build_pb2.Build]: ...
    def __init__(
        self,
        *,
        build: collections.abc.Iterable[qwak.build.v1.build_pb2.Build] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build"]) -> None: ...

global___ListBuildsResponse = ListBuildsResponse

class RegisterTagsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "tags", b"tags"]) -> None: ...

global___RegisterTagsRequest = RegisterTagsRequest

class RegisterTagsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterTagsResponse = RegisterTagsResponse

class LogPhaseStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    PHASE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PHASE_DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    phase_id: builtins.str
    status: global___PhaseStatus.ValueType
    phase_duration_in_seconds: builtins.int
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        phase_id: builtins.str = ...,
        status: global___PhaseStatus.ValueType = ...,
        phase_duration_in_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "phase_duration_in_seconds", b"phase_duration_in_seconds", "phase_id", b"phase_id", "status", b"status"]) -> None: ...

global___LogPhaseStatusRequest = LogPhaseStatusRequest

class LogPhaseStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___LogPhaseStatusResponse = LogPhaseStatusResponse

class GetPhaseStatusesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___GetPhaseStatusesRequest = GetPhaseStatusesRequest

class PhaseStatusLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHASE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PHASE_DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    POD_FAILURE_REASON_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    phase_id: builtins.str
    status: global___PhaseStatus.ValueType
    phase_duration_in_seconds: builtins.int
    pod_failure_reason: global___FailureReason.ValueType
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        phase_id: builtins.str = ...,
        status: global___PhaseStatus.ValueType = ...,
        phase_duration_in_seconds: builtins.int = ...,
        pod_failure_reason: global___FailureReason.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "last_modified_at", b"last_modified_at", "phase_duration_in_seconds", b"phase_duration_in_seconds", "phase_id", b"phase_id", "pod_failure_reason", b"pod_failure_reason", "status", b"status"]) -> None: ...

global___PhaseStatusLog = PhaseStatusLog

class GetPhaseStatusesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUSES_FIELD_NUMBER: builtins.int
    @property
    def statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PhaseStatusLog]: ...
    def __init__(
        self,
        *,
        statuses: collections.abc.Iterable[global___PhaseStatusLog] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["statuses", b"statuses"]) -> None: ...

global___GetPhaseStatusesResponse = GetPhaseStatusesResponse

class DeleteBuildRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_IDS_FIELD_NUMBER: builtins.int
    @property
    def build_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        build_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_ids", b"build_ids"]) -> None: ...

global___DeleteBuildRequest = DeleteBuildRequest

class DeleteBuildResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteBuildResponse = DeleteBuildResponse

class GetTagPathRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    MODEL_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    TAG_NAME_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    model_id: builtins.str
    build_id: builtins.str
    tag_name: builtins.str
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        model_id: builtins.str = ...,
        build_id: builtins.str = ...,
        tag_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "environment_id", b"environment_id", "model_id", b"model_id", "tag_name", b"tag_name"]) -> None: ...

global___GetTagPathRequest = GetTagPathRequest

class GetTagPathResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_PATH_FIELD_NUMBER: builtins.int
    key_path: builtins.str
    def __init__(
        self,
        *,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_path", b"key_path"]) -> None: ...

global___GetTagPathResponse = GetTagPathResponse

class RerunBuildFromExistingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXISTING_BUILD_ID_FIELD_NUMBER: builtins.int
    NEW_BUILD_CONFIGURATION_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    PURCHASE_OPTION_FIELD_NUMBER: builtins.int
    existing_build_id: builtins.str
    @property
    def new_build_configuration(self) -> qwak.build.v1.build_pb2.BuildConfiguration: ...
    @property
    def resources(self) -> qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources:
        """Build pod compute resources"""
    purchase_option: qwak.fitness_service.fitness_pb2.PurchaseOption.ValueType
    def __init__(
        self,
        *,
        existing_build_id: builtins.str = ...,
        new_build_configuration: qwak.build.v1.build_pb2.BuildConfiguration | None = ...,
        resources: qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources | None = ...,
        purchase_option: qwak.fitness_service.fitness_pb2.PurchaseOption.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["new_build_configuration", b"new_build_configuration", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["existing_build_id", b"existing_build_id", "new_build_configuration", b"new_build_configuration", "purchase_option", b"purchase_option", "resources", b"resources"]) -> None: ...

global___RerunBuildFromExistingRequest = RerunBuildFromExistingRequest

class RerunBuildFromExistingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RerunBuildFromExistingResponse = RerunBuildFromExistingResponse

class GetBuildsArtifactsScanSummaryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    ARTIFACT_NAME_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """The build id to bring scans for"""
    artifact_name: builtins.str
    """The artifact name to get summary for"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        artifact_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_name", b"artifact_name", "build_id", b"build_id"]) -> None: ...

global___GetBuildsArtifactsScanSummaryRequest = GetBuildsArtifactsScanSummaryRequest

class GetBuildsArtifactsScanSummaryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ResultByArtifactNameEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.build.v1.build_pb2.ScanResultSummary: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.build.v1.build_pb2.ScanResultSummary | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESULT_FIELD_NUMBER: builtins.int
    UI_DIRECT_LINK_FIELD_NUMBER: builtins.int
    RESULT_BY_ARTIFACT_NAME_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> qwak.build.v1.build_pb2.ScanResultSummary:
        """The scan result summary"""
    ui_direct_link: builtins.str
    """Ui link scan result"""
    @property
    def result_by_artifact_name(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.build.v1.build_pb2.ScanResultSummary]: ...
    def __init__(
        self,
        *,
        result: qwak.build.v1.build_pb2.ScanResultSummary | None = ...,
        ui_direct_link: builtins.str = ...,
        result_by_artifact_name: collections.abc.Mapping[builtins.str, qwak.build.v1.build_pb2.ScanResultSummary] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result", "result_by_artifact_name", b"result_by_artifact_name", "ui_direct_link", b"ui_direct_link"]) -> None: ...

global___GetBuildsArtifactsScanSummaryResponse = GetBuildsArtifactsScanSummaryResponse

class GetBuildImageDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    environment_id: builtins.str
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "environment_id", b"environment_id"]) -> None: ...

global___GetBuildImageDetailsRequest = GetBuildImageDetailsRequest

class GetBuildImageDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_IMAGE_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def build_image_details(self) -> qwak.build.v1.build_pb2.BuildImageDetails: ...
    def __init__(
        self,
        *,
        build_image_details: qwak.build.v1.build_pb2.BuildImageDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_image_details", b"build_image_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_image_details", b"build_image_details"]) -> None: ...

global___GetBuildImageDetailsResponse = GetBuildImageDetailsResponse



from abc import ABC, abstractmethod
from dataclasses import dataclass
from typing import List, Optional


class DataType(ABC):
    @abstractmethod
    def to_ddl(self) -> str:
        pass


@dataclass
class SimpleType(DataType):
    type_name: str

    def to_ddl(self) -> str:
        return self.type_name


@dataclass
class ArrayType(DataType):
    type: DataType

    def to_ddl(self) -> str:
        return f"array<{self.type.to_ddl()}>"


class Type:
    array = ArrayType
    int = SimpleType("integer")
    long = SimpleType("long")
    string = SimpleType("string")
    double = SimpleType("double")
    decimal = SimpleType("decimal")
    float = SimpleType("float")
    boolean = SimpleType("boolean")
    timestamp = SimpleType("timestamp")
    date = SimpleType("date")


@dataclass
class Column:
    type: DataType
    name: Optional[str] = None

    def to_ddl(self) -> str:
        if self.name:
            return f"{self.name} {self.type.to_ddl()}"
        return self.type.to_ddl()


@dataclass
class Schema:
    columns: List[Column]

    def to_ddl(self) -> str:
        return ", ".join([column.to_ddl() for column in self.columns])



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.feature_store.features.execution_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BackfillSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    INTERVAL_BACKFILL_FIELD_NUMBER: builtins.int
    FULL_RESET_BACKFILL_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    BACKFILL_TYPE_FIELD_NUMBER: builtins.int
    NO_OVERRIDE_FIELD_NUMBER: builtins.int
    EXPLICIT_CONFIGURATION_FIELD_NUMBER: builtins.int
    BACKFILL_ID_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """name of the featureset"""
    @property
    def interval_backfill(self) -> global___IntervalBackfillWindow:
        """finite interval. the start of the interval
        must not be prior to the featureset's backfill start
        """
    @property
    def full_reset_backfill(self) -> global___FullResetBackfillWindow:
        """Full reset"""
    comment: builtins.str
    """Optional comment for this backfill"""
    @property
    def backfill_type(self) -> global___BackfillType:
        """type of backfill (scheduled/incremental etc.)"""
    @property
    def no_override(self) -> global___ImplicitResourceConfiguration:
        """no override of the resources - take what's already defined for that FS"""
    @property
    def explicit_configuration(self) -> global___ExplicitResourceConfiguration:
        """use ad-hoc configuration just for the backfill"""
    backfill_id: builtins.str
    """ID of this backfill - set by the service
    upon submitting the backfill request (a value set by the client is ignored)
    """
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        interval_backfill: global___IntervalBackfillWindow | None = ...,
        full_reset_backfill: global___FullResetBackfillWindow | None = ...,
        comment: builtins.str = ...,
        backfill_type: global___BackfillType | None = ...,
        no_override: global___ImplicitResourceConfiguration | None = ...,
        explicit_configuration: global___ExplicitResourceConfiguration | None = ...,
        backfill_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill_type", b"backfill_type", "backfill_window_type", b"backfill_window_type", "explicit_configuration", b"explicit_configuration", "full_reset_backfill", b"full_reset_backfill", "interval_backfill", b"interval_backfill", "no_override", b"no_override", "resource_configuration_type", b"resource_configuration_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill_id", b"backfill_id", "backfill_type", b"backfill_type", "backfill_window_type", b"backfill_window_type", "comment", b"comment", "explicit_configuration", b"explicit_configuration", "featureset_name", b"featureset_name", "full_reset_backfill", b"full_reset_backfill", "interval_backfill", b"interval_backfill", "no_override", b"no_override", "resource_configuration_type", b"resource_configuration_type"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["backfill_window_type", b"backfill_window_type"]) -> typing_extensions.Literal["interval_backfill", "full_reset_backfill"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["resource_configuration_type", b"resource_configuration_type"]) -> typing_extensions.Literal["no_override", "explicit_configuration"] | None: ...

global___BackfillSpec = BackfillSpec

class ImplicitResourceConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ImplicitResourceConfiguration = ImplicitResourceConfiguration

class ExplicitResourceConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_TEMPLATE_FIELD_NUMBER: builtins.int
    cluster_template: qwak.feature_store.features.execution_pb2.ClusterTemplate.ValueType
    def __init__(
        self,
        *,
        cluster_template: qwak.feature_store.features.execution_pb2.ClusterTemplate.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_template", b"cluster_template", "resource_config_type", b"resource_config_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_template", b"cluster_template", "resource_config_type", b"resource_config_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["resource_config_type", b"resource_config_type"]) -> typing_extensions.Literal["cluster_template"] | None: ...

global___ExplicitResourceConfiguration = ExplicitResourceConfiguration

class BackfillType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AS_SCHEDULED_FIELD_NUMBER: builtins.int
    @property
    def as_scheduled(self) -> global___AsScheduledBackfillType:
        """as-scheduled, batches are performed according to the cron"""
    def __init__(
        self,
        *,
        as_scheduled: global___AsScheduledBackfillType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["as_scheduled", b"as_scheduled", "backfill_type", b"backfill_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["as_scheduled", b"as_scheduled", "backfill_type", b"backfill_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["backfill_type", b"backfill_type"]) -> typing_extensions.Literal["as_scheduled"] | None: ...

global___BackfillType = BackfillType

class AsScheduledBackfillType(google.protobuf.message.Message):
    """backfill that runs as scheduled, meaning all logical batches are performed"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AsScheduledBackfillType = AsScheduledBackfillType

class IntervalBackfillWindow(google.protobuf.message.Message):
    """represents a backfill window where a (finite) interval is being replaced"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKFILL_START_FIELD_NUMBER: builtins.int
    BACKFILL_END_FIELD_NUMBER: builtins.int
    @property
    def backfill_start(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the start of the backfill"""
    @property
    def backfill_end(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the end of the backfill"""
    def __init__(
        self,
        *,
        backfill_start: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        backfill_end: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill_end", b"backfill_end", "backfill_start", b"backfill_start"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill_end", b"backfill_end", "backfill_start", b"backfill_start"]) -> None: ...

global___IntervalBackfillWindow = IntervalBackfillWindow

class FullResetBackfillWindow(google.protobuf.message.Message):
    """represents a complete reset, everything is replaced.
    note that in this case the start of the backfill is inferred from the
    featureset definition
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FullResetBackfillWindow = FullResetBackfillWindow



import grpc
from _qwak_proto.qwak.administration.v0.authentication.authentication_service_pb2 import (
    AuthenticateRequest,
    QwakApiKeyMethod,
)
from _qwak_proto.qwak.administration.v0.authentication.authentication_service_pb2_grpc import (
    AuthenticationServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class AuthenticationClient:
    """
    Used for interacting with Qwak's Authentication service
    """

    def __init__(
        self, grpc_channel=Provide[QwakContainer.unauthenticated_core_grpc_channel]
    ):
        self._authentication_service = AuthenticationServiceStub(grpc_channel)

    def authenticate(self, api_key=None):
        request = AuthenticateRequest(
            qwak_api_key_method=QwakApiKeyMethod(qwak_api_key=api_key)
        )
        try:
            return self._authentication_service.Authenticate(request)
        except grpc.RpcError as e:
            raise QwakException(f"Failed to login, error is {e.details()}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/build/v1/build_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.build.v1 import build_pb2 as qwak_dot_build_dot_v1_dot_build__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.fitness_service import fitness_pb2 as qwak_dot_fitness__service_dot_fitness__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dqwak/build/v1/build_api.proto\x12\x11\x63om.qwak.build.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19qwak/build/v1/build.proto\x1a/qwak/user_application/common/v0/resources.proto\x1a\"qwak/fitness_service/fitness.proto\"R\n\x1aSaveFrameworkModelsRequest\x12\x34\n\x04spec\x18\x01 \x01(\x0b\x32&.com.qwak.build.v1.FrameworkModelsSpec\"\x1d\n\x1bSaveFrameworkModelsResponse\"|\n\x14RegisterBuildRequest\x12\x0f\n\x07\x62uildId\x18\x01 \x01(\t\x12\x10\n\x08\x63ommitId\x18\x02 \x01(\t\x12\x0f\n\x07modelId\x18\x03 \x01(\t\x12\x13\n\x0b\x62uildConfig\x18\x04 \x01(\t\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12\r\n\x05steps\x18\x06 \x03(\t\"\x17\n\x15RegisterBuildResponse\"a\n\x18UpdateBuildStatusRequest\x12\x0f\n\x07\x62uildId\x18\x01 \x01(\t\x12\x34\n\x0c\x62uild_status\x18\x02 \x01(\x0e\x32\x1e.com.qwak.build.v1.BuildStatus\"\x1b\n\x19UpdateBuildStatusResponse\"\xba\x02\n!RegisterExperimentTrackingRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12P\n\x06params\x18\x02 \x03(\x0b\x32@.com.qwak.build.v1.RegisterExperimentTrackingRequest.ParamsEntry\x12R\n\x07metrics\x18\x03 \x03(\x0b\x32\x41.com.qwak.build.v1.RegisterExperimentTrackingRequest.MetricsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"$\n\"RegisterExperimentTrackingResponse\"d\n\x1aRegisterModelSchemaRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x34\n\x0cmodel_schema\x18\x02 \x01(\x0b\x32\x1e.com.qwak.build.v1.ModelSchema\"\x1d\n\x1bRegisterModelSchemaResponse\"#\n\x0fGetBuildRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\";\n\x10GetBuildResponse\x12\'\n\x05\x62uild\x18\x01 \x01(\x0b\x32\x18.com.qwak.build.v1.Build\"n\n\x11ListBuildsRequest\x12\x15\n\tbranch_id\x18\x01 \x01(\tB\x02\x18\x01\x12.\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1e.com.qwak.build.v1.BuildFilter\x12\x12\n\nmodel_uuid\x18\x03 \x01(\t\"=\n\x12ListBuildsResponse\x12\'\n\x05\x62uild\x18\x01 \x03(\x0b\x32\x18.com.qwak.build.v1.Build\"5\n\x13RegisterTagsRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x16\n\x14RegisterTagsResponse\"\x8e\x01\n\x15LogPhaseStatusRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x10\n\x08phase_id\x18\x02 \x01(\t\x12.\n\x06status\x18\x03 \x01(\x0e\x32\x1e.com.qwak.build.v1.PhaseStatus\x12!\n\x19phase_duration_in_seconds\x18\x04 \x01(\x05\"\x18\n\x16LogPhaseStatusResponse\"+\n\x17GetPhaseStatusesRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"\x99\x02\n\x0ePhaseStatusLog\x12\x10\n\x08phase_id\x18\x01 \x01(\t\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.com.qwak.build.v1.PhaseStatus\x12!\n\x19phase_duration_in_seconds\x18\x03 \x01(\x05\x12<\n\x12pod_failure_reason\x18\x04 \x01(\x0e\x32 .com.qwak.build.v1.FailureReason\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"O\n\x18GetPhaseStatusesResponse\x12\x33\n\x08statuses\x18\x01 \x03(\x0b\x32!.com.qwak.build.v1.PhaseStatusLog\"\'\n\x12\x44\x65leteBuildRequest\x12\x11\n\tbuild_ids\x18\x01 \x03(\t\"\x15\n\x13\x44\x65leteBuildResponse\"a\n\x11GetTagPathRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x10\n\x08tag_name\x18\x04 \x01(\t\"&\n\x12GetTagPathResponse\x12\x10\n\x08key_path\x18\x01 \x01(\t\"\x90\x02\n\x1dRerunBuildFromExistingRequest\x12\x19\n\x11\x65xisting_build_id\x18\x01 \x01(\t\x12\x46\n\x17new_build_configuration\x18\x02 \x01(\x0b\x32%.com.qwak.build.v1.BuildConfiguration\x12M\n\tresources\x18\x03 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12=\n\x0fpurchase_option\x18\x04 \x01(\x0e\x32$.qwak.fitness.service.PurchaseOption\" \n\x1eRerunBuildFromExistingResponse\"S\n$GetBuildsArtifactsScanSummaryRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x19\n\rartifact_name\x18\x02 \x01(\tB\x02\x18\x01\"\xd5\x02\n%GetBuildsArtifactsScanSummaryResponse\x12\x38\n\x06result\x18\x01 \x01(\x0b\x32$.com.qwak.build.v1.ScanResultSummaryB\x02\x18\x01\x12\x1a\n\x0eui_direct_link\x18\x02 \x01(\tB\x02\x18\x01\x12s\n\x17result_by_artifact_name\x18\x03 \x03(\x0b\x32R.com.qwak.build.v1.GetBuildsArtifactsScanSummaryResponse.ResultByArtifactNameEntry\x1a\x61\n\x19ResultByArtifactNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.com.qwak.build.v1.ScanResultSummary:\x02\x38\x01\"G\n\x1bGetBuildImageDetailsRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"a\n\x1cGetBuildImageDetailsResponse\x12\x41\n\x13\x62uild_image_details\x18\x01 \x01(\x0b\x32$.com.qwak.build.v1.BuildImageDetails*\x97\x01\n\x0bPhaseStatus\x12\x18\n\x14PHASE_STATUS_INVALID\x10\x00\x12\x1c\n\x18PHASE_STATUS_IN_PROGRESS\x10\x01\x12\x1b\n\x17PHASE_STATUS_SUCCESSFUL\x10\x02\x12\x17\n\x13PHASE_STATUS_FAILED\x10\x03\x12\x1a\n\x16PHASE_STATUS_CANCELLED\x10\x04*w\n\rFailureReason\x12\x1e\n\x1a\x46\x41ILURE_REASON_UNSPECIFIED\x10\x00\x12$\n FAILURE_REASON_AVAILABLE_IN_LOGS\x10\x01\x12 \n\x1c\x46\x41ILURE_REASON_OUT_OF_MEMORY\x10\x02\x32\x81\r\n\x08\x42uildAPI\x12\x62\n\rRegisterBuild\x12\'.com.qwak.build.v1.RegisterBuildRequest\x1a(.com.qwak.build.v1.RegisterBuildResponse\x12n\n\x11UpdateBuildStatus\x12+.com.qwak.build.v1.UpdateBuildStatusRequest\x1a,.com.qwak.build.v1.UpdateBuildStatusResponse\x12\x89\x01\n\x1aRegisterExperimentTracking\x12\x34.com.qwak.build.v1.RegisterExperimentTrackingRequest\x1a\x35.com.qwak.build.v1.RegisterExperimentTrackingResponse\x12_\n\x0cRegisterTags\x12&.com.qwak.build.v1.RegisterTagsRequest\x1a\'.com.qwak.build.v1.RegisterTagsResponse\x12t\n\x13RegisterModelSchema\x12-.com.qwak.build.v1.RegisterModelSchemaRequest\x1a..com.qwak.build.v1.RegisterModelSchemaResponse\x12S\n\x08GetBuild\x12\".com.qwak.build.v1.GetBuildRequest\x1a#.com.qwak.build.v1.GetBuildResponse\x12Y\n\nListBuilds\x12$.com.qwak.build.v1.ListBuildsRequest\x1a%.com.qwak.build.v1.ListBuildsResponse\x12\\\n\x0b\x44\x65leteBuild\x12%.com.qwak.build.v1.DeleteBuildRequest\x1a&.com.qwak.build.v1.DeleteBuildResponse\x12\x65\n\x0eLogPhaseStatus\x12(.com.qwak.build.v1.LogPhaseStatusRequest\x1a).com.qwak.build.v1.LogPhaseStatusResponse\x12k\n\x10GetPhaseStatuses\x12*.com.qwak.build.v1.GetPhaseStatusesRequest\x1a+.com.qwak.build.v1.GetPhaseStatusesResponse\x12Y\n\nGetTagPath\x12$.com.qwak.build.v1.GetTagPathRequest\x1a%.com.qwak.build.v1.GetTagPathResponse\x12}\n\x16RerunBuildFromExisting\x12\x30.com.qwak.build.v1.RerunBuildFromExistingRequest\x1a\x31.com.qwak.build.v1.RerunBuildFromExistingResponse\x12t\n\x13SaveFrameworkModels\x12-.com.qwak.build.v1.SaveFrameworkModelsRequest\x1a..com.qwak.build.v1.SaveFrameworkModelsResponse\x12\x92\x01\n\x1dGetBuildsArtifactsScanSummary\x12\x37.com.qwak.build.v1.GetBuildsArtifactsScanSummaryRequest\x1a\x38.com.qwak.build.v1.GetBuildsArtifactsScanSummaryResponse\x12w\n\x14GetBuildImageDetails\x12..com.qwak.build.v1.GetBuildImageDetailsRequest\x1a/.com.qwak.build.v1.GetBuildImageDetailsResponseB$\n\x11\x63om.qwak.build.v1B\rBuildApiProtoP\x01\x62\x06proto3')

_PHASESTATUS = DESCRIPTOR.enum_types_by_name['PhaseStatus']
PhaseStatus = enum_type_wrapper.EnumTypeWrapper(_PHASESTATUS)
_FAILUREREASON = DESCRIPTOR.enum_types_by_name['FailureReason']
FailureReason = enum_type_wrapper.EnumTypeWrapper(_FAILUREREASON)
PHASE_STATUS_INVALID = 0
PHASE_STATUS_IN_PROGRESS = 1
PHASE_STATUS_SUCCESSFUL = 2
PHASE_STATUS_FAILED = 3
PHASE_STATUS_CANCELLED = 4
FAILURE_REASON_UNSPECIFIED = 0
FAILURE_REASON_AVAILABLE_IN_LOGS = 1
FAILURE_REASON_OUT_OF_MEMORY = 2


_SAVEFRAMEWORKMODELSREQUEST = DESCRIPTOR.message_types_by_name['SaveFrameworkModelsRequest']
_SAVEFRAMEWORKMODELSRESPONSE = DESCRIPTOR.message_types_by_name['SaveFrameworkModelsResponse']
_REGISTERBUILDREQUEST = DESCRIPTOR.message_types_by_name['RegisterBuildRequest']
_REGISTERBUILDRESPONSE = DESCRIPTOR.message_types_by_name['RegisterBuildResponse']
_UPDATEBUILDSTATUSREQUEST = DESCRIPTOR.message_types_by_name['UpdateBuildStatusRequest']
_UPDATEBUILDSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateBuildStatusResponse']
_REGISTEREXPERIMENTTRACKINGREQUEST = DESCRIPTOR.message_types_by_name['RegisterExperimentTrackingRequest']
_REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY = _REGISTEREXPERIMENTTRACKINGREQUEST.nested_types_by_name['ParamsEntry']
_REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY = _REGISTEREXPERIMENTTRACKINGREQUEST.nested_types_by_name['MetricsEntry']
_REGISTEREXPERIMENTTRACKINGRESPONSE = DESCRIPTOR.message_types_by_name['RegisterExperimentTrackingResponse']
_REGISTERMODELSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['RegisterModelSchemaRequest']
_REGISTERMODELSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['RegisterModelSchemaResponse']
_GETBUILDREQUEST = DESCRIPTOR.message_types_by_name['GetBuildRequest']
_GETBUILDRESPONSE = DESCRIPTOR.message_types_by_name['GetBuildResponse']
_LISTBUILDSREQUEST = DESCRIPTOR.message_types_by_name['ListBuildsRequest']
_LISTBUILDSRESPONSE = DESCRIPTOR.message_types_by_name['ListBuildsResponse']
_REGISTERTAGSREQUEST = DESCRIPTOR.message_types_by_name['RegisterTagsRequest']
_REGISTERTAGSRESPONSE = DESCRIPTOR.message_types_by_name['RegisterTagsResponse']
_LOGPHASESTATUSREQUEST = DESCRIPTOR.message_types_by_name['LogPhaseStatusRequest']
_LOGPHASESTATUSRESPONSE = DESCRIPTOR.message_types_by_name['LogPhaseStatusResponse']
_GETPHASESTATUSESREQUEST = DESCRIPTOR.message_types_by_name['GetPhaseStatusesRequest']
_PHASESTATUSLOG = DESCRIPTOR.message_types_by_name['PhaseStatusLog']
_GETPHASESTATUSESRESPONSE = DESCRIPTOR.message_types_by_name['GetPhaseStatusesResponse']
_DELETEBUILDREQUEST = DESCRIPTOR.message_types_by_name['DeleteBuildRequest']
_DELETEBUILDRESPONSE = DESCRIPTOR.message_types_by_name['DeleteBuildResponse']
_GETTAGPATHREQUEST = DESCRIPTOR.message_types_by_name['GetTagPathRequest']
_GETTAGPATHRESPONSE = DESCRIPTOR.message_types_by_name['GetTagPathResponse']
_RERUNBUILDFROMEXISTINGREQUEST = DESCRIPTOR.message_types_by_name['RerunBuildFromExistingRequest']
_RERUNBUILDFROMEXISTINGRESPONSE = DESCRIPTOR.message_types_by_name['RerunBuildFromExistingResponse']
_GETBUILDSARTIFACTSSCANSUMMARYREQUEST = DESCRIPTOR.message_types_by_name['GetBuildsArtifactsScanSummaryRequest']
_GETBUILDSARTIFACTSSCANSUMMARYRESPONSE = DESCRIPTOR.message_types_by_name['GetBuildsArtifactsScanSummaryResponse']
_GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY = _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE.nested_types_by_name['ResultByArtifactNameEntry']
_GETBUILDIMAGEDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetBuildImageDetailsRequest']
_GETBUILDIMAGEDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetBuildImageDetailsResponse']
SaveFrameworkModelsRequest = _reflection.GeneratedProtocolMessageType('SaveFrameworkModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVEFRAMEWORKMODELSREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.SaveFrameworkModelsRequest)
  })
_sym_db.RegisterMessage(SaveFrameworkModelsRequest)

SaveFrameworkModelsResponse = _reflection.GeneratedProtocolMessageType('SaveFrameworkModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVEFRAMEWORKMODELSRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.SaveFrameworkModelsResponse)
  })
_sym_db.RegisterMessage(SaveFrameworkModelsResponse)

RegisterBuildRequest = _reflection.GeneratedProtocolMessageType('RegisterBuildRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERBUILDREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterBuildRequest)
  })
_sym_db.RegisterMessage(RegisterBuildRequest)

RegisterBuildResponse = _reflection.GeneratedProtocolMessageType('RegisterBuildResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERBUILDRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterBuildResponse)
  })
_sym_db.RegisterMessage(RegisterBuildResponse)

UpdateBuildStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateBuildStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUILDSTATUSREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.UpdateBuildStatusRequest)
  })
_sym_db.RegisterMessage(UpdateBuildStatusRequest)

UpdateBuildStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateBuildStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUILDSTATUSRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.UpdateBuildStatusResponse)
  })
_sym_db.RegisterMessage(UpdateBuildStatusResponse)

RegisterExperimentTrackingRequest = _reflection.GeneratedProtocolMessageType('RegisterExperimentTrackingRequest', (_message.Message,), {

  'ParamsEntry' : _reflection.GeneratedProtocolMessageType('ParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY,
    '__module__' : 'qwak.build.v1.build_api_pb2'
    # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterExperimentTrackingRequest.ParamsEntry)
    })
  ,

  'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
    'DESCRIPTOR' : _REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY,
    '__module__' : 'qwak.build.v1.build_api_pb2'
    # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterExperimentTrackingRequest.MetricsEntry)
    })
  ,
  'DESCRIPTOR' : _REGISTEREXPERIMENTTRACKINGREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterExperimentTrackingRequest)
  })
_sym_db.RegisterMessage(RegisterExperimentTrackingRequest)
_sym_db.RegisterMessage(RegisterExperimentTrackingRequest.ParamsEntry)
_sym_db.RegisterMessage(RegisterExperimentTrackingRequest.MetricsEntry)

RegisterExperimentTrackingResponse = _reflection.GeneratedProtocolMessageType('RegisterExperimentTrackingResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEREXPERIMENTTRACKINGRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterExperimentTrackingResponse)
  })
_sym_db.RegisterMessage(RegisterExperimentTrackingResponse)

RegisterModelSchemaRequest = _reflection.GeneratedProtocolMessageType('RegisterModelSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERMODELSCHEMAREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterModelSchemaRequest)
  })
_sym_db.RegisterMessage(RegisterModelSchemaRequest)

RegisterModelSchemaResponse = _reflection.GeneratedProtocolMessageType('RegisterModelSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERMODELSCHEMARESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterModelSchemaResponse)
  })
_sym_db.RegisterMessage(RegisterModelSchemaResponse)

GetBuildRequest = _reflection.GeneratedProtocolMessageType('GetBuildRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetBuildRequest)
  })
_sym_db.RegisterMessage(GetBuildRequest)

GetBuildResponse = _reflection.GeneratedProtocolMessageType('GetBuildResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetBuildResponse)
  })
_sym_db.RegisterMessage(GetBuildResponse)

ListBuildsRequest = _reflection.GeneratedProtocolMessageType('ListBuildsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUILDSREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ListBuildsRequest)
  })
_sym_db.RegisterMessage(ListBuildsRequest)

ListBuildsResponse = _reflection.GeneratedProtocolMessageType('ListBuildsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUILDSRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ListBuildsResponse)
  })
_sym_db.RegisterMessage(ListBuildsResponse)

RegisterTagsRequest = _reflection.GeneratedProtocolMessageType('RegisterTagsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERTAGSREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterTagsRequest)
  })
_sym_db.RegisterMessage(RegisterTagsRequest)

RegisterTagsResponse = _reflection.GeneratedProtocolMessageType('RegisterTagsResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERTAGSRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RegisterTagsResponse)
  })
_sym_db.RegisterMessage(RegisterTagsResponse)

LogPhaseStatusRequest = _reflection.GeneratedProtocolMessageType('LogPhaseStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGPHASESTATUSREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.LogPhaseStatusRequest)
  })
_sym_db.RegisterMessage(LogPhaseStatusRequest)

LogPhaseStatusResponse = _reflection.GeneratedProtocolMessageType('LogPhaseStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGPHASESTATUSRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.LogPhaseStatusResponse)
  })
_sym_db.RegisterMessage(LogPhaseStatusResponse)

GetPhaseStatusesRequest = _reflection.GeneratedProtocolMessageType('GetPhaseStatusesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPHASESTATUSESREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetPhaseStatusesRequest)
  })
_sym_db.RegisterMessage(GetPhaseStatusesRequest)

PhaseStatusLog = _reflection.GeneratedProtocolMessageType('PhaseStatusLog', (_message.Message,), {
  'DESCRIPTOR' : _PHASESTATUSLOG,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.PhaseStatusLog)
  })
_sym_db.RegisterMessage(PhaseStatusLog)

GetPhaseStatusesResponse = _reflection.GeneratedProtocolMessageType('GetPhaseStatusesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPHASESTATUSESRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetPhaseStatusesResponse)
  })
_sym_db.RegisterMessage(GetPhaseStatusesResponse)

DeleteBuildRequest = _reflection.GeneratedProtocolMessageType('DeleteBuildRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBUILDREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.DeleteBuildRequest)
  })
_sym_db.RegisterMessage(DeleteBuildRequest)

DeleteBuildResponse = _reflection.GeneratedProtocolMessageType('DeleteBuildResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBUILDRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.DeleteBuildResponse)
  })
_sym_db.RegisterMessage(DeleteBuildResponse)

GetTagPathRequest = _reflection.GeneratedProtocolMessageType('GetTagPathRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTAGPATHREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetTagPathRequest)
  })
_sym_db.RegisterMessage(GetTagPathRequest)

GetTagPathResponse = _reflection.GeneratedProtocolMessageType('GetTagPathResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTAGPATHRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetTagPathResponse)
  })
_sym_db.RegisterMessage(GetTagPathResponse)

RerunBuildFromExistingRequest = _reflection.GeneratedProtocolMessageType('RerunBuildFromExistingRequest', (_message.Message,), {
  'DESCRIPTOR' : _RERUNBUILDFROMEXISTINGREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RerunBuildFromExistingRequest)
  })
_sym_db.RegisterMessage(RerunBuildFromExistingRequest)

RerunBuildFromExistingResponse = _reflection.GeneratedProtocolMessageType('RerunBuildFromExistingResponse', (_message.Message,), {
  'DESCRIPTOR' : _RERUNBUILDFROMEXISTINGRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RerunBuildFromExistingResponse)
  })
_sym_db.RegisterMessage(RerunBuildFromExistingResponse)

GetBuildsArtifactsScanSummaryRequest = _reflection.GeneratedProtocolMessageType('GetBuildsArtifactsScanSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDSARTIFACTSSCANSUMMARYREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetBuildsArtifactsScanSummaryRequest)
  })
_sym_db.RegisterMessage(GetBuildsArtifactsScanSummaryRequest)

GetBuildsArtifactsScanSummaryResponse = _reflection.GeneratedProtocolMessageType('GetBuildsArtifactsScanSummaryResponse', (_message.Message,), {

  'ResultByArtifactNameEntry' : _reflection.GeneratedProtocolMessageType('ResultByArtifactNameEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY,
    '__module__' : 'qwak.build.v1.build_api_pb2'
    # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetBuildsArtifactsScanSummaryResponse.ResultByArtifactNameEntry)
    })
  ,
  'DESCRIPTOR' : _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetBuildsArtifactsScanSummaryResponse)
  })
_sym_db.RegisterMessage(GetBuildsArtifactsScanSummaryResponse)
_sym_db.RegisterMessage(GetBuildsArtifactsScanSummaryResponse.ResultByArtifactNameEntry)

GetBuildImageDetailsRequest = _reflection.GeneratedProtocolMessageType('GetBuildImageDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDIMAGEDETAILSREQUEST,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetBuildImageDetailsRequest)
  })
_sym_db.RegisterMessage(GetBuildImageDetailsRequest)

GetBuildImageDetailsResponse = _reflection.GeneratedProtocolMessageType('GetBuildImageDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDIMAGEDETAILSRESPONSE,
  '__module__' : 'qwak.build.v1.build_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.GetBuildImageDetailsResponse)
  })
_sym_db.RegisterMessage(GetBuildImageDetailsResponse)

_BUILDAPI = DESCRIPTOR.services_by_name['BuildAPI']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.qwak.build.v1B\rBuildApiProtoP\001'
  _REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY._options = None
  _REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY._serialized_options = b'8\001'
  _REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY._options = None
  _REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY._serialized_options = b'8\001'
  _LISTBUILDSREQUEST.fields_by_name['branch_id']._options = None
  _LISTBUILDSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _GETBUILDSARTIFACTSSCANSUMMARYREQUEST.fields_by_name['artifact_name']._options = None
  _GETBUILDSARTIFACTSSCANSUMMARYREQUEST.fields_by_name['artifact_name']._serialized_options = b'\030\001'
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY._options = None
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY._serialized_options = b'8\001'
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE.fields_by_name['result']._options = None
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE.fields_by_name['result']._serialized_options = b'\030\001'
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE.fields_by_name['ui_direct_link']._options = None
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE.fields_by_name['ui_direct_link']._serialized_options = b'\030\001'
  _PHASESTATUS._serialized_start=3126
  _PHASESTATUS._serialized_end=3277
  _FAILUREREASON._serialized_start=3279
  _FAILUREREASON._serialized_end=3398
  _SAVEFRAMEWORKMODELSREQUEST._serialized_start=197
  _SAVEFRAMEWORKMODELSREQUEST._serialized_end=279
  _SAVEFRAMEWORKMODELSRESPONSE._serialized_start=281
  _SAVEFRAMEWORKMODELSRESPONSE._serialized_end=310
  _REGISTERBUILDREQUEST._serialized_start=312
  _REGISTERBUILDREQUEST._serialized_end=436
  _REGISTERBUILDRESPONSE._serialized_start=438
  _REGISTERBUILDRESPONSE._serialized_end=461
  _UPDATEBUILDSTATUSREQUEST._serialized_start=463
  _UPDATEBUILDSTATUSREQUEST._serialized_end=560
  _UPDATEBUILDSTATUSRESPONSE._serialized_start=562
  _UPDATEBUILDSTATUSRESPONSE._serialized_end=589
  _REGISTEREXPERIMENTTRACKINGREQUEST._serialized_start=592
  _REGISTEREXPERIMENTTRACKINGREQUEST._serialized_end=906
  _REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY._serialized_start=813
  _REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY._serialized_end=858
  _REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY._serialized_start=860
  _REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY._serialized_end=906
  _REGISTEREXPERIMENTTRACKINGRESPONSE._serialized_start=908
  _REGISTEREXPERIMENTTRACKINGRESPONSE._serialized_end=944
  _REGISTERMODELSCHEMAREQUEST._serialized_start=946
  _REGISTERMODELSCHEMAREQUEST._serialized_end=1046
  _REGISTERMODELSCHEMARESPONSE._serialized_start=1048
  _REGISTERMODELSCHEMARESPONSE._serialized_end=1077
  _GETBUILDREQUEST._serialized_start=1079
  _GETBUILDREQUEST._serialized_end=1114
  _GETBUILDRESPONSE._serialized_start=1116
  _GETBUILDRESPONSE._serialized_end=1175
  _LISTBUILDSREQUEST._serialized_start=1177
  _LISTBUILDSREQUEST._serialized_end=1287
  _LISTBUILDSRESPONSE._serialized_start=1289
  _LISTBUILDSRESPONSE._serialized_end=1350
  _REGISTERTAGSREQUEST._serialized_start=1352
  _REGISTERTAGSREQUEST._serialized_end=1405
  _REGISTERTAGSRESPONSE._serialized_start=1407
  _REGISTERTAGSRESPONSE._serialized_end=1429
  _LOGPHASESTATUSREQUEST._serialized_start=1432
  _LOGPHASESTATUSREQUEST._serialized_end=1574
  _LOGPHASESTATUSRESPONSE._serialized_start=1576
  _LOGPHASESTATUSRESPONSE._serialized_end=1600
  _GETPHASESTATUSESREQUEST._serialized_start=1602
  _GETPHASESTATUSESREQUEST._serialized_end=1645
  _PHASESTATUSLOG._serialized_start=1648
  _PHASESTATUSLOG._serialized_end=1929
  _GETPHASESTATUSESRESPONSE._serialized_start=1931
  _GETPHASESTATUSESRESPONSE._serialized_end=2010
  _DELETEBUILDREQUEST._serialized_start=2012
  _DELETEBUILDREQUEST._serialized_end=2051
  _DELETEBUILDRESPONSE._serialized_start=2053
  _DELETEBUILDRESPONSE._serialized_end=2074
  _GETTAGPATHREQUEST._serialized_start=2076
  _GETTAGPATHREQUEST._serialized_end=2173
  _GETTAGPATHRESPONSE._serialized_start=2175
  _GETTAGPATHRESPONSE._serialized_end=2213
  _RERUNBUILDFROMEXISTINGREQUEST._serialized_start=2216
  _RERUNBUILDFROMEXISTINGREQUEST._serialized_end=2488
  _RERUNBUILDFROMEXISTINGRESPONSE._serialized_start=2490
  _RERUNBUILDFROMEXISTINGRESPONSE._serialized_end=2522
  _GETBUILDSARTIFACTSSCANSUMMARYREQUEST._serialized_start=2524
  _GETBUILDSARTIFACTSSCANSUMMARYREQUEST._serialized_end=2607
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE._serialized_start=2610
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE._serialized_end=2951
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY._serialized_start=2854
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY._serialized_end=2951
  _GETBUILDIMAGEDETAILSREQUEST._serialized_start=2953
  _GETBUILDIMAGEDETAILSREQUEST._serialized_end=3024
  _GETBUILDIMAGEDETAILSRESPONSE._serialized_start=3026
  _GETBUILDIMAGEDETAILSRESPONSE._serialized_end=3123
  _BUILDAPI._serialized_start=3401
  _BUILDAPI._serialized_end=5066
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/opsgenie_integration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/integration/opsgenie_integration.proto\x12\x1bqwak.integration.management\"\xb7\x02\n\x13OpsgenieIntegration\x12[\n\x1e\x65ncrypted_opsgenie_auth_config\x18\x01 \x01(\x0b\x32/.qwak.integration.management.OpsgenieAuthConfigB\x02\x18\x01\x12H\n\x11opsgenie_settings\x18\x02 \x01(\x0b\x32-.qwak.integration.management.OpsgenieSettings\x12\x10\n\x08\x62\x61se_url\x18\x03 \x01(\t\x12_\n\x17opsgeinie_system_secret\x18\x04 \x01(\x0b\x32<.qwak.integration.management.OpsgeinieSystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"\xc3\x01\n\x17OpsgenieIntegrationSpec\x12H\n\x11opsgenie_settings\x18\x02 \x01(\x0b\x32-.qwak.integration.management.OpsgenieSettings\x12V\n\x1bopsgenie_auth_configuration\x18\x03 \x01(\x0b\x32/.qwak.integration.management.OpsgenieAuthConfigH\x00\x42\x06\n\x04\x61uth\"O\n\x10OpsgenieSettings\x12;\n\x06region\x18\x02 \x01(\x0e\x32+.qwak.integration.management.OpsgenieRegion\"%\n\x12OpsgenieAuthConfig\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\"R\n\x1fOpsgeinieSystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12\x1a\n\x12\x61pi_key_secret_key\x18\x02 \x01(\t\"\xa4\x01\n\x16OpsgenieValidationSpec\x12M\n\x14opsgenie_auth_config\x18\x01 \x01(\x0b\x32/.qwak.integration.management.OpsgenieAuthConfig\x12;\n\x06region\x18\x02 \x01(\x0e\x32+.qwak.integration.management.OpsgenieRegion\"\x1c\n\x1aOpsgenieIntegrationOptions*]\n\x0eOpsgenieRegion\x12\x1b\n\x17OPSGENIE_REGION_INVALID\x10\x00\x12\x16\n\x12OPSGENIE_REGION_US\x10\x01\x12\x16\n\x12OPSGENIE_REGION_EU\x10\x02\x42H\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_OPSGENIEREGION = DESCRIPTOR.enum_types_by_name['OpsgenieRegion']
OpsgenieRegion = enum_type_wrapper.EnumTypeWrapper(_OPSGENIEREGION)
OPSGENIE_REGION_INVALID = 0
OPSGENIE_REGION_US = 1
OPSGENIE_REGION_EU = 2


_OPSGENIEINTEGRATION = DESCRIPTOR.message_types_by_name['OpsgenieIntegration']
_OPSGENIEINTEGRATIONSPEC = DESCRIPTOR.message_types_by_name['OpsgenieIntegrationSpec']
_OPSGENIESETTINGS = DESCRIPTOR.message_types_by_name['OpsgenieSettings']
_OPSGENIEAUTHCONFIG = DESCRIPTOR.message_types_by_name['OpsgenieAuthConfig']
_OPSGEINIESYSTEMSECRETDESCRIPTOR = DESCRIPTOR.message_types_by_name['OpsgeinieSystemSecretDescriptor']
_OPSGENIEVALIDATIONSPEC = DESCRIPTOR.message_types_by_name['OpsgenieValidationSpec']
_OPSGENIEINTEGRATIONOPTIONS = DESCRIPTOR.message_types_by_name['OpsgenieIntegrationOptions']
OpsgenieIntegration = _reflection.GeneratedProtocolMessageType('OpsgenieIntegration', (_message.Message,), {
  'DESCRIPTOR' : _OPSGENIEINTEGRATION,
  '__module__' : 'qwak.integration.opsgenie_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.OpsgenieIntegration)
  })
_sym_db.RegisterMessage(OpsgenieIntegration)

OpsgenieIntegrationSpec = _reflection.GeneratedProtocolMessageType('OpsgenieIntegrationSpec', (_message.Message,), {
  'DESCRIPTOR' : _OPSGENIEINTEGRATIONSPEC,
  '__module__' : 'qwak.integration.opsgenie_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.OpsgenieIntegrationSpec)
  })
_sym_db.RegisterMessage(OpsgenieIntegrationSpec)

OpsgenieSettings = _reflection.GeneratedProtocolMessageType('OpsgenieSettings', (_message.Message,), {
  'DESCRIPTOR' : _OPSGENIESETTINGS,
  '__module__' : 'qwak.integration.opsgenie_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.OpsgenieSettings)
  })
_sym_db.RegisterMessage(OpsgenieSettings)

OpsgenieAuthConfig = _reflection.GeneratedProtocolMessageType('OpsgenieAuthConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPSGENIEAUTHCONFIG,
  '__module__' : 'qwak.integration.opsgenie_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.OpsgenieAuthConfig)
  })
_sym_db.RegisterMessage(OpsgenieAuthConfig)

OpsgeinieSystemSecretDescriptor = _reflection.GeneratedProtocolMessageType('OpsgeinieSystemSecretDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _OPSGEINIESYSTEMSECRETDESCRIPTOR,
  '__module__' : 'qwak.integration.opsgenie_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.OpsgeinieSystemSecretDescriptor)
  })
_sym_db.RegisterMessage(OpsgeinieSystemSecretDescriptor)

OpsgenieValidationSpec = _reflection.GeneratedProtocolMessageType('OpsgenieValidationSpec', (_message.Message,), {
  'DESCRIPTOR' : _OPSGENIEVALIDATIONSPEC,
  '__module__' : 'qwak.integration.opsgenie_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.OpsgenieValidationSpec)
  })
_sym_db.RegisterMessage(OpsgenieValidationSpec)

OpsgenieIntegrationOptions = _reflection.GeneratedProtocolMessageType('OpsgenieIntegrationOptions', (_message.Message,), {
  'DESCRIPTOR' : _OPSGENIEINTEGRATIONOPTIONS,
  '__module__' : 'qwak.integration.opsgenie_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.OpsgenieIntegrationOptions)
  })
_sym_db.RegisterMessage(OpsgenieIntegrationOptions)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _OPSGENIEINTEGRATION.fields_by_name['encrypted_opsgenie_auth_config']._options = None
  _OPSGENIEINTEGRATION.fields_by_name['encrypted_opsgenie_auth_config']._serialized_options = b'\030\001'
  _OPSGENIEREGION._serialized_start=989
  _OPSGENIEREGION._serialized_end=1082
  _OPSGENIEINTEGRATION._serialized_start=77
  _OPSGENIEINTEGRATION._serialized_end=388
  _OPSGENIEINTEGRATIONSPEC._serialized_start=391
  _OPSGENIEINTEGRATIONSPEC._serialized_end=586
  _OPSGENIESETTINGS._serialized_start=588
  _OPSGENIESETTINGS._serialized_end=667
  _OPSGENIEAUTHCONFIG._serialized_start=669
  _OPSGENIEAUTHCONFIG._serialized_end=706
  _OPSGEINIESYSTEMSECRETDESCRIPTOR._serialized_start=708
  _OPSGEINIESYSTEMSECRETDESCRIPTOR._serialized_end=790
  _OPSGENIEVALIDATIONSPEC._serialized_start=793
  _OPSGENIEVALIDATIONSPEC._serialized_end=957
  _OPSGENIEINTEGRATIONOPTIONS._serialized_start=959
  _OPSGENIEINTEGRATIONOPTIONS._serialized_end=987
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BuildSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_REPOSITORY_SETTING_FIELD_NUMBER: builtins.int
    @property
    def model_repository_setting(self) -> global___ModelRepositorySettings: ...
    def __init__(
        self,
        *,
        model_repository_setting: global___ModelRepositorySettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_repository_setting", b"model_repository_setting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_repository_setting", b"model_repository_setting"]) -> None: ...

global___BuildSettings = BuildSettings

class ModelRepositorySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_REGISTRY_PREFIX_FIELD_NUMBER: builtins.int
    REPOSITORY_SETTINGS_ECR_FIELD_NUMBER: builtins.int
    REPOSITORY_SETTINGS_JFROG_FIELD_NUMBER: builtins.int
    REPOSITORY_SETTINGS_GCR_FIELD_NUMBER: builtins.int
    container_registry_prefix: builtins.str
    @property
    def repository_settings_ecr(self) -> global___RepositorySettingsECR: ...
    @property
    def repository_settings_jfrog(self) -> global___RepositorySettingsJFrog: ...
    @property
    def repository_settings_gcr(self) -> global___RepositorySettingsGCR: ...
    def __init__(
        self,
        *,
        container_registry_prefix: builtins.str = ...,
        repository_settings_ecr: global___RepositorySettingsECR | None = ...,
        repository_settings_jfrog: global___RepositorySettingsJFrog | None = ...,
        repository_settings_gcr: global___RepositorySettingsGCR | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repository_settings_ecr", b"repository_settings_ecr", "repository_settings_gcr", b"repository_settings_gcr", "repository_settings_jfrog", b"repository_settings_jfrog", "repository_type", b"repository_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_registry_prefix", b"container_registry_prefix", "repository_settings_ecr", b"repository_settings_ecr", "repository_settings_gcr", b"repository_settings_gcr", "repository_settings_jfrog", b"repository_settings_jfrog", "repository_type", b"repository_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["repository_type", b"repository_type"]) -> typing_extensions.Literal["repository_settings_ecr", "repository_settings_jfrog", "repository_settings_gcr"] | None: ...

global___ModelRepositorySettings = ModelRepositorySettings

class RepositorySettingsJFrog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_SETTINGS_FIELD_NUMBER: builtins.int
    JFROG_PROJECT_NAME_FIELD_NUMBER: builtins.int
    EXTERNAL_REPOSITORY_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def authentication_settings(self) -> global___AuthenticationSettings: ...
    jfrog_project_name: builtins.str
    @property
    def external_repository_settings(self) -> global___ExternalRepositorySettings:
        """Setting for external repositories to be used during the build"""
    def __init__(
        self,
        *,
        authentication_settings: global___AuthenticationSettings | None = ...,
        jfrog_project_name: builtins.str = ...,
        external_repository_settings: global___ExternalRepositorySettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_settings", b"authentication_settings", "external_repository_settings", b"external_repository_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_settings", b"authentication_settings", "external_repository_settings", b"external_repository_settings", "jfrog_project_name", b"jfrog_project_name"]) -> None: ...

global___RepositorySettingsJFrog = RepositorySettingsJFrog

class ExternalRepositorySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PYTHON_REPOSITORY_FIELD_NUMBER: builtins.int
    HUGGINGFACE_REPOSITORY_FIELD_NUMBER: builtins.int
    ALLOW_EXTERNAL_PYTHON_REPOSITORIES_FIELD_NUMBER: builtins.int
    VIRTUAL_PYTHON_DEPENDENCIES_REPOSITORY_FIELD_NUMBER: builtins.int
    @property
    def python_repository(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of private python repositories to be used by the build"""
    huggingface_repository: builtins.str
    """A HuggingFace remote proxy to be used by the build"""
    allow_external_python_repositories: builtins.bool
    """Allow external python repositories to be used"""
    virtual_python_dependencies_repository: builtins.str
    """The virtual python repository to use"""
    def __init__(
        self,
        *,
        python_repository: collections.abc.Iterable[builtins.str] | None = ...,
        huggingface_repository: builtins.str = ...,
        allow_external_python_repositories: builtins.bool = ...,
        virtual_python_dependencies_repository: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_external_python_repositories", b"allow_external_python_repositories", "huggingface_repository", b"huggingface_repository", "python_repository", b"python_repository", "virtual_python_dependencies_repository", b"virtual_python_dependencies_repository"]) -> None: ...

global___ExternalRepositorySettings = ExternalRepositorySettings

class AuthenticationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    token: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token", "username", b"username"]) -> None: ...

global___AuthenticationSettings = AuthenticationSettings

class RepositorySettingsECR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RepositorySettingsECR = RepositorySettingsECR

class RepositorySettingsGCR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RepositorySettingsGCR = RepositorySettingsGCR



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.sources import batch_pb2 as qwak_dot_feature__store_dot_sources_dot_batch__pb2
from _qwak_proto.qwak.feature_store.sources import streaming_pb2 as qwak_dot_feature__store_dot_sources_dot_streaming__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/feature_store/sources/data_source.proto\x12\x1aqwak.feature.store.sources\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&qwak/feature_store/sources/batch.proto\x1a*qwak/feature_store/sources/streaming.proto\"\xe3\x01\n\nDataSource\x12P\n\x16\x64\x61ta_source_definition\x18\x01 \x01(\x0b\x32\x30.qwak.feature.store.sources.DataSourceDefinition\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32..qwak.feature.store.sources.DataSourceMetadata\x12\x41\n\x0c\x66\x65\x61ture_sets\x18\x03 \x03(\x0b\x32+.qwak.feature.store.sources.FeatureSetBrief\"t\n\x14\x44\x61taSourceDefinition\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x44\n\x10\x64\x61ta_source_spec\x18\x02 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"\xa8\x01\n\x12\x44\x61taSourceMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"\x9f\x01\n\x0e\x44\x61taSourceSpec\x12?\n\x0c\x62\x61tch_source\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.sources.BatchSourceH\x00\x12\x44\n\rstream_source\x18\x02 \x01(\x0b\x32+.qwak.feature.store.sources.StreamingSourceH\x00\x42\x06\n\x04type\"]\n\x0f\x46\x65\x61tureSetBrief\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_type\x18\x03 \x01(\x05\x42X\n%com.qwak.ai.feature.store.sources.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')



_DATASOURCE = DESCRIPTOR.message_types_by_name['DataSource']
_DATASOURCEDEFINITION = DESCRIPTOR.message_types_by_name['DataSourceDefinition']
_DATASOURCEMETADATA = DESCRIPTOR.message_types_by_name['DataSourceMetadata']
_DATASOURCESPEC = DESCRIPTOR.message_types_by_name['DataSourceSpec']
_FEATURESETBRIEF = DESCRIPTOR.message_types_by_name['FeatureSetBrief']
DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

DataSourceDefinition = _reflection.GeneratedProtocolMessageType('DataSourceDefinition', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEDEFINITION,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DataSourceDefinition)
  })
_sym_db.RegisterMessage(DataSourceDefinition)

DataSourceMetadata = _reflection.GeneratedProtocolMessageType('DataSourceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEMETADATA,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DataSourceMetadata)
  })
_sym_db.RegisterMessage(DataSourceMetadata)

DataSourceSpec = _reflection.GeneratedProtocolMessageType('DataSourceSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESPEC,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DataSourceSpec)
  })
_sym_db.RegisterMessage(DataSourceSpec)

FeatureSetBrief = _reflection.GeneratedProtocolMessageType('FeatureSetBrief', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETBRIEF,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.FeatureSetBrief)
  })
_sym_db.RegisterMessage(FeatureSetBrief)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.sources.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _DATASOURCE._serialized_start=194
  _DATASOURCE._serialized_end=421
  _DATASOURCEDEFINITION._serialized_start=423
  _DATASOURCEDEFINITION._serialized_end=539
  _DATASOURCEMETADATA._serialized_start=542
  _DATASOURCEMETADATA._serialized_end=710
  _DATASOURCESPEC._serialized_start=713
  _DATASOURCESPEC._serialized_end=872
  _FEATURESETBRIEF._serialized_start=874
  _FEATURESETBRIEF._serialized_end=967
# @@protoc_insertion_point(module_scope)



from typing import Callable

from dependency_injector.wiring import Provide, inject

from qwak.exceptions import QwakException
from qwak.inner.runtime_di.containers import QwakRuntimeContainer
from qwak.model.adapters.input_adapters.base_input_adapter import BaseInputAdapter
from qwak.model.adapters.input_adapters.dataframe_input_adapter import (
    DataFrameInputAdapter,
)
from qwak.model.adapters.output_adapters.base_output_adapter import BaseOutputAdapter
from qwak.model.adapters.output_adapters.dataframe_output_adapter import (
    DataFrameOutputAdapter,
)

API_NOT_CONFIGURED_ERROR_MESSAGE = (
    "There has been an error configuring the Qwak model. When testing locally, "
    "please use 'run_local' as described in our docs: "
    "https://docs-saas.qwak.com/docs/testing-locally#running-local-inference"
)


@inject
def api_decorator(
    analytics: bool = True,
    analytics_sample_ratio: float = 1.0,
    analytics_exclude_columns: list = [],
    feature_extraction: bool = False,
    input_adapter: BaseInputAdapter = DataFrameInputAdapter(),
    output_adapter: BaseOutputAdapter = DataFrameOutputAdapter(),
    api_decorator_function_creator=Provide[
        QwakRuntimeContainer.api_decorator_function_creator
    ],
) -> Callable:
    if callable(analytics):
        raise TypeError(
            """
        You forgot to call the `@api` decorator.

        Correct way -
        @api()
        def function():
            pass

        Wrong way -
        @api
        def function():
            pass
        """
        )
    try:
        return api_decorator_function_creator(
            analytics,
            feature_extraction,
            input_adapter,
            output_adapter,
            analytics_sample_ratio,
            analytics_exclude_columns,
        )
    except TypeError as e:
        if "__call__() takes 1" in str(e):
            raise QwakException(API_NOT_CONFIGURED_ERROR_MESSAGE)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.vectors.v1.filters_pb2
import qwak.vectors.v1.vector_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SearchSimilarVectorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_NAME_FIELD_NUMBER: builtins.int
    REFERENCE_VECTOR_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    MAX_RESULTS_FIELD_NUMBER: builtins.int
    INCLUDE_VECTOR_FIELD_NUMBER: builtins.int
    INCLUDE_DISTANCE_FIELD_NUMBER: builtins.int
    INCLUDE_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    collection_name: builtins.str
    """Name of the collection to search in"""
    @property
    def reference_vector(self) -> qwak.vectors.v1.vector_pb2.DoubleVector:
        """Reference vector"""
    @property
    def properties(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """properties to retrieve"""
    @property
    def filter(self) -> qwak.vectors.v1.filters_pb2.Filter: ...
    max_results: builtins.int
    """the "k" in top_k"""
    include_vector: builtins.bool
    """whether to include the actual result vectors in the response"""
    include_distance: builtins.bool
    """whether to include the distance in the result"""
    include_id: builtins.bool
    """whether to include ids in the result"""
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        collection_name: builtins.str = ...,
        reference_vector: qwak.vectors.v1.vector_pb2.DoubleVector | None = ...,
        properties: collections.abc.Iterable[builtins.str] | None = ...,
        filter: qwak.vectors.v1.filters_pb2.Filter | None = ...,
        max_results: builtins.int = ...,
        include_vector: builtins.bool = ...,
        include_distance: builtins.bool = ...,
        include_id: builtins.bool = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter", "filter_opt", b"filter_opt", "optional_tenant", b"optional_tenant", "reference_vector", b"reference_vector", "tenant_id", b"tenant_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_name", b"collection_name", "filter", b"filter", "filter_opt", b"filter_opt", "include_distance", b"include_distance", "include_id", b"include_id", "include_vector", b"include_vector", "max_results", b"max_results", "optional_tenant", b"optional_tenant", "properties", b"properties", "reference_vector", b"reference_vector", "tenant_id", b"tenant_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["filter_opt", b"filter_opt"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_tenant", b"optional_tenant"]) -> typing_extensions.Literal["tenant_id"] | None: ...

global___SearchSimilarVectorsRequest = SearchSimilarVectorsRequest

class SearchSimilarVectorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def search_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.vectors.v1.vector_pb2.SearchResult]: ...
    def __init__(
        self,
        *,
        search_results: collections.abc.Iterable[qwak.vectors.v1.vector_pb2.SearchResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["search_results", b"search_results"]) -> None: ...

global___SearchSimilarVectorsResponse = SearchSimilarVectorsResponse

class GetVectorSampleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_NAME_FIELD_NUMBER: builtins.int
    NUM_SAMPLES_FIELD_NUMBER: builtins.int
    INCLUDE_VECTOR_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    collection_name: builtins.str
    """Name of the collection to search in"""
    num_samples: builtins.int
    """Number of samples to retrieve"""
    include_vector: builtins.bool
    """Whether to include the actual result vectors in the response"""
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        collection_name: builtins.str = ...,
        num_samples: builtins.int = ...,
        include_vector: builtins.bool = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["optional_tenant", b"optional_tenant", "tenant_id", b"tenant_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_name", b"collection_name", "include_vector", b"include_vector", "num_samples", b"num_samples", "optional_tenant", b"optional_tenant", "tenant_id", b"tenant_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_tenant", b"optional_tenant"]) -> typing_extensions.Literal["tenant_id"] | None: ...

global___GetVectorSampleRequest = GetVectorSampleRequest

class GetVectorSampleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VECTORS_FIELD_NUMBER: builtins.int
    @property
    def vectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.vectors.v1.vector_pb2.StoredVector]: ...
    def __init__(
        self,
        *,
        vectors: collections.abc.Iterable[qwak.vectors.v1.vector_pb2.StoredVector] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["vectors", b"vectors"]) -> None: ...

global___GetVectorSampleResponse = GetVectorSampleResponse

class UpsertVectorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_NAME_FIELD_NUMBER: builtins.int
    VECTOR_FIELD_NUMBER: builtins.int
    collection_name: builtins.str
    @property
    def vector(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.vectors.v1.vector_pb2.StoredVector]: ...
    def __init__(
        self,
        *,
        collection_name: builtins.str = ...,
        vector: collections.abc.Iterable[qwak.vectors.v1.vector_pb2.StoredVector] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_name", b"collection_name", "vector", b"vector"]) -> None: ...

global___UpsertVectorsRequest = UpsertVectorsRequest

class UpsertVectorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_AFFECTED_FIELD_NUMBER: builtins.int
    num_affected: builtins.int
    """number of vectors that were affected in the collection"""
    def __init__(
        self,
        *,
        num_affected: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_affected", b"num_affected"]) -> None: ...

global___UpsertVectorsResponse = UpsertVectorsResponse

class DeleteVectorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_NAME_FIELD_NUMBER: builtins.int
    VECTOR_ID_FIELD_NUMBER: builtins.int
    VECTOR_IDENTIFIERS_FIELD_NUMBER: builtins.int
    collection_name: builtins.str
    @property
    def vector_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """passing explicit id is now deprecated, pass a VectorIdentifier"""
    @property
    def vector_identifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.vectors.v1.vector_pb2.VectorIdentifier]: ...
    def __init__(
        self,
        *,
        collection_name: builtins.str = ...,
        vector_id: collections.abc.Iterable[builtins.str] | None = ...,
        vector_identifiers: collections.abc.Iterable[qwak.vectors.v1.vector_pb2.VectorIdentifier] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_name", b"collection_name", "vector_id", b"vector_id", "vector_identifiers", b"vector_identifiers"]) -> None: ...

global___DeleteVectorsRequest = DeleteVectorsRequest

class DeleteVectorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_VECTORS_DELETED_FIELD_NUMBER: builtins.int
    num_vectors_deleted: builtins.int
    def __init__(
        self,
        *,
        num_vectors_deleted: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_vectors_deleted", b"num_vectors_deleted"]) -> None: ...

global___DeleteVectorsResponse = DeleteVectorsResponse

class FetchVectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_NAME_FIELD_NUMBER: builtins.int
    VECTOR_ID_FIELD_NUMBER: builtins.int
    VECTOR_IDENTIFIER_FIELD_NUMBER: builtins.int
    collection_name: builtins.str
    """Name of the collection to fetch from"""
    vector_id: builtins.str
    """Vector id to fetch - this field is deprecated, use VectorIdentifier"""
    @property
    def vector_identifier(self) -> qwak.vectors.v1.vector_pb2.VectorIdentifier:
        """Vector identifier to fetch"""
    def __init__(
        self,
        *,
        collection_name: builtins.str = ...,
        vector_id: builtins.str = ...,
        vector_identifier: qwak.vectors.v1.vector_pb2.VectorIdentifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vector_identifier", b"vector_identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_name", b"collection_name", "vector_id", b"vector_id", "vector_identifier", b"vector_identifier"]) -> None: ...

global___FetchVectorRequest = FetchVectorRequest

class FetchVectorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VECTOR_FIELD_NUMBER: builtins.int
    @property
    def vector(self) -> qwak.vectors.v1.vector_pb2.StoredVector:
        """Fetched vector"""
    def __init__(
        self,
        *,
        vector: qwak.vectors.v1.vector_pb2.StoredVector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vector", b"vector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["vector", b"vector"]) -> None: ...

global___FetchVectorResponse = FetchVectorResponse



from .base import QwakConfigBase, YamlConfigMixin
from .utils import (
    ConfigCliMap,
    validate_bool,
    validate_enum,
    validate_float,
    validate_int,
    validate_list_of_strings,
    validate_positive_int,
    validate_purchase_option,
    validate_string,
)



import dataclasses

from qwak_services_mock.mocks import workspace_manager_service_mock
from qwak_services_mock.mocks.alert_manager_service_api import (
    AlertManagerServiceApiMock,
)
from qwak_services_mock.mocks.alert_registry_service_api import (
    AlertsRegistryServiceApiMock,
)
from qwak_services_mock.mocks.analytics_api import AnalyticsApiMock
from qwak_services_mock.mocks.audience_service_api import AudienceServiceApiMock
from qwak_services_mock.mocks.authentication_service import AuthenticationServiceMock
from qwak_services_mock.mocks.automation_management_service import (
    AutomationManagementServiceMock,
)
from qwak_services_mock.mocks.autoscaling_service_api import AutoscalingServiceApiMock
from qwak_services_mock.mocks.batch_job_manager_service import BatchJobManagerService
from qwak_services_mock.mocks.build_management import BuildsManagementServiceMock
from qwak_services_mock.mocks.build_orchestrator_build_api import (
    BuildOrchestratorBuildApiMock,
)
from qwak_services_mock.mocks.build_orchestrator_build_settings_api import (
    BuildOrchestratorBuildSettingsApiMock,
)
from qwak_services_mock.mocks.build_orchestrator_service_api import (
    BuildOrchestratorServiceApiMock,
)
from qwak_services_mock.mocks.data_versioning_service import DataVersioningServiceMock
from qwak_services_mock.mocks.deployment_management_service import (
    DeploymentManagementServiceMock,
)
from qwak_services_mock.mocks.ecosystem_service_api import EcoSystemServiceMock
from qwak_services_mock.mocks.execution_management_service import (
    ExecutionManagementServiceMock,
)
from qwak_services_mock.mocks.feature_store_data_sources_manager_api import (
    DataSourceServiceMock,
)
from qwak_services_mock.mocks.feature_store_entities_manager_api import (
    EntityServiceMock,
)
from qwak_services_mock.mocks.feature_store_feature_set_manager_api import (
    FeatureSetServiceMock,
)
from qwak_services_mock.mocks.features_operator_v3_service import (
    FeaturesOperatorV3ServiceMock,
)
from qwak_services_mock.mocks.file_versioning_service import FileVersioningServiceMock
from qwak_services_mock.mocks.fs_offline_serving_service import (
    FsOfflineServingServiceMock,
)
from qwak_services_mock.mocks.instance_template_management_service import (
    InstanceTemplateManagementServiceMock,
)
from qwak_services_mock.mocks.integration_management_service import (
    IntegrationManagementServiceMock,
)
from qwak_services_mock.mocks.internal_build_orchestrator_service import (
    InternalBuildOrchestratorServiceMock,
)
from qwak_services_mock.mocks.job_registry_service_api import JobRegistryServiceApiMock
from qwak_services_mock.mocks.kube_captain_service_api import KubeCaptainServiceApiMock
from qwak_services_mock.mocks.logging_service import LoggingServiceApiMock
from qwak_services_mock.mocks.model_management_service import (
    ModelsManagementServiceMock,
)
from qwak_services_mock.mocks.project_manager_service import ProjectManagerServiceMock
from qwak_services_mock.mocks.prompt_manager_service import PromptManagerServiceMock
from qwak_services_mock.mocks.secret_service import SecretServiceMock
from qwak_services_mock.mocks.self_service_user_service import (
    SelfServiceUserServiceMock,
)
from qwak_services_mock.mocks.system_secret_service import SystemSecretServiceMock
from qwak_services_mock.mocks.user_application_instance_service_api import (
    UserApplicationInstanceServiceApiMock,
)
from qwak_services_mock.mocks.vector_serving_api import VectorServingServiceMock
from qwak_services_mock.mocks.vectors_management_api import (
    VectorCollectionManagementServiceMock,
)


@dataclasses.dataclass
class QwakMocks:
    port: int
    build_orchestrator_build_api: BuildOrchestratorBuildApiMock
    build_orchestrator_service_api: BuildOrchestratorServiceApiMock
    build_orchestrator_build_settings_api: BuildOrchestratorBuildSettingsApiMock
    internal_build_orchestrator_service: InternalBuildOrchestratorServiceMock
    build_management_service_mock: BuildsManagementServiceMock
    alert_manager_service_mock: AlertManagerServiceApiMock
    automation_management_service_mock: AutomationManagementServiceMock
    job_registry_service_mock: JobRegistryServiceApiMock
    project_manager_service_mock: ProjectManagerServiceMock
    kube_captain_service_mock: KubeCaptainServiceApiMock
    file_versioning_service_mock: FileVersioningServiceMock
    data_versioning_service_mock: DataVersioningServiceMock
    model_management_service_mock: ModelsManagementServiceMock
    logging_service_mock: LoggingServiceApiMock
    autoscaling_service_mock: AutoscalingServiceApiMock
    audience_api_mock: AudienceServiceApiMock
    self_service_user_service_mock: SelfServiceUserServiceMock
    analytics_api_mock: AnalyticsApiMock
    deployment_management_service_mock: DeploymentManagementServiceMock
    batch_job_manager_service: BatchJobManagerService
    ecosystem_client_mock: EcoSystemServiceMock
    user_application_instance_service_mock: UserApplicationInstanceServiceApiMock
    secret_service_mock: SecretServiceMock
    authentication_service_mock: AuthenticationServiceMock
    features_operator_service: FeaturesOperatorV3ServiceMock
    fs_offline_serving_service: FsOfflineServingServiceMock
    fs_data_sources_service: DataSourceServiceMock
    fs_entities_service: EntityServiceMock
    fs_feature_sets_service: FeatureSetServiceMock
    instance_templates_service: InstanceTemplateManagementServiceMock
    alerts_registry_service: AlertsRegistryServiceApiMock
    workspace_manager_service: workspace_manager_service_mock
    vector_serving_service: VectorServingServiceMock
    vector_collection_service: VectorCollectionManagementServiceMock
    execution_management_service: ExecutionManagementServiceMock
    system_secret_service: SystemSecretServiceMock
    integration_management_service: IntegrationManagementServiceMock
    prompt_manager_service: PromptManagerServiceMock



from dataclasses import dataclass

from _qwak_proto.qwak.feature_store.features.feature_set_pb2 import (
    FeatureSetUserMetadata as ProtoMetadata,
)

_METADATA_ATTRIBUTE = "_qwak_metadata"


def set_metadata_on_function(
    function, owner: str = "", description: str = "", display_name: str = ""
):
    setattr(
        function,
        _METADATA_ATTRIBUTE,
        Metadata(owner=owner, description=description, display_name=display_name),
    )


def get_metadata_from_function(
    function, owner: str = "", description: str = "", display_name: str = ""
):
    return getattr(
        function,
        _METADATA_ATTRIBUTE,
        Metadata(owner=owner, description=description, display_name=display_name),
    )


@dataclass
class Metadata:
    owner: str = ""
    description: str = ""
    display_name: str = ""

    @staticmethod
    def from_proto(metadata: ProtoMetadata):
        return Metadata(metadata.owner, metadata.description, metadata.display_name)

    def to_proto(self):
        return ProtoMetadata(
            owner=self.owner,
            description=self.description,
            display_name=self.display_name,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/execution.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/feature_store/features/execution.proto\x12%qwak.feature.store.features.execution\"\xcb\x01\n\rExecutionSpec\x12R\n\x10\x63luster_template\x18\x01 \x01(\x0e\x32\x36.qwak.feature.store.features.execution.ClusterTemplateH\x00\x12^\n\x16resource_configuration\x18\x02 \x01(\x0b\x32<.qwak.feature.store.features.execution.ResourceConfigurationH\x00\x42\x06\n\x04spec\"\xcf\x03\n\x16StreamingExecutionSpec\x12Y\n\x17online_cluster_template\x18\x01 \x01(\x0e\x32\x36.qwak.feature.store.features.execution.ClusterTemplateH\x00\x12\x65\n\x1donline_resource_configuration\x18\x02 \x01(\x0b\x32<.qwak.feature.store.features.execution.ResourceConfigurationH\x00\x12Z\n\x18offline_cluster_template\x18\x03 \x01(\x0e\x32\x36.qwak.feature.store.features.execution.ClusterTemplateH\x01\x12\x66\n\x1eoffline_resource_configuration\x18\x04 \x01(\x0b\x32<.qwak.feature.store.features.execution.ResourceConfigurationH\x01\x42\x16\n\x14online_resource_specB\x17\n\x15offline_resource_spec\"\xe5\x01\n\x15\x42\x61\x63kfillExecutionSpec\x12R\n\x10\x63luster_template\x18\x01 \x01(\x0e\x32\x36.qwak.feature.store.features.execution.ClusterTemplateH\x00\x12^\n\x16resource_configuration\x18\x02 \x01(\x0b\x32<.qwak.feature.store.features.execution.ResourceConfigurationH\x00\x42\x18\n\x16\x62\x61\x63kfill_resource_spec\"\xbe\x01\n\x15ResourceConfiguration\x12\x15\n\rdriver_memory\x18\x01 \x01(\t\x12\x14\n\x0c\x64river_cores\x18\x02 \x01(\x05\x12\x19\n\x11initial_executors\x18\x03 \x01(\x05\x12\x15\n\rmin_executors\x18\x04 \x01(\x05\x12\x15\n\rmax_executors\x18\x05 \x01(\x05\x12\x17\n\x0f\x65xecutor_memory\x18\x06 \x01(\t\x12\x16\n\x0e\x65xecutor_cores\x18\x07 \x01(\x05*d\n\x0f\x43lusterTemplate\x12\t\n\x05SMALL\x10\x00\x12\n\n\x06MEDIUM\x10\x01\x12\t\n\x05LARGE\x10\x02\x12\n\n\x06XLARGE\x10\x03\x12\x0b\n\x07XXLARGE\x10\x04\x12\x0c\n\x08XXXLARGE\x10\x05\x12\x08\n\x04NANO\x10\x06\x42[\n&com.qwak.ai.feature.store.features.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_CLUSTERTEMPLATE = DESCRIPTOR.enum_types_by_name['ClusterTemplate']
ClusterTemplate = enum_type_wrapper.EnumTypeWrapper(_CLUSTERTEMPLATE)
SMALL = 0
MEDIUM = 1
LARGE = 2
XLARGE = 3
XXLARGE = 4
XXXLARGE = 5
NANO = 6


_EXECUTIONSPEC = DESCRIPTOR.message_types_by_name['ExecutionSpec']
_STREAMINGEXECUTIONSPEC = DESCRIPTOR.message_types_by_name['StreamingExecutionSpec']
_BACKFILLEXECUTIONSPEC = DESCRIPTOR.message_types_by_name['BackfillExecutionSpec']
_RESOURCECONFIGURATION = DESCRIPTOR.message_types_by_name['ResourceConfiguration']
ExecutionSpec = _reflection.GeneratedProtocolMessageType('ExecutionSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONSPEC,
  '__module__' : 'qwak.feature_store.features.execution_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.execution.ExecutionSpec)
  })
_sym_db.RegisterMessage(ExecutionSpec)

StreamingExecutionSpec = _reflection.GeneratedProtocolMessageType('StreamingExecutionSpec', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGEXECUTIONSPEC,
  '__module__' : 'qwak.feature_store.features.execution_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.execution.StreamingExecutionSpec)
  })
_sym_db.RegisterMessage(StreamingExecutionSpec)

BackfillExecutionSpec = _reflection.GeneratedProtocolMessageType('BackfillExecutionSpec', (_message.Message,), {
  'DESCRIPTOR' : _BACKFILLEXECUTIONSPEC,
  '__module__' : 'qwak.feature_store.features.execution_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.execution.BackfillExecutionSpec)
  })
_sym_db.RegisterMessage(BackfillExecutionSpec)

ResourceConfiguration = _reflection.GeneratedProtocolMessageType('ResourceConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCECONFIGURATION,
  '__module__' : 'qwak.feature_store.features.execution_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.execution.ResourceConfiguration)
  })
_sym_db.RegisterMessage(ResourceConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.features.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _CLUSTERTEMPLATE._serialized_start=1183
  _CLUSTERTEMPLATE._serialized_end=1283
  _EXECUTIONSPEC._serialized_start=87
  _EXECUTIONSPEC._serialized_end=290
  _STREAMINGEXECUTIONSPEC._serialized_start=293
  _STREAMINGEXECUTIONSPEC._serialized_end=756
  _BACKFILLEXECUTIONSPEC._serialized_start=759
  _BACKFILLEXECUTIONSPEC._serialized_end=988
  _RESOURCECONFIGURATION._serialized_start=991
  _RESOURCECONFIGURATION._serialized_end=1181
# @@protoc_insertion_point(module_scope)
